@@ -51,23 +51,3 @@ class RefBase:
 
     def __eq__(self, other):
         return self.value.__eq__(other)
-
-    def __add__(self, other):
-        self._base_value_setter(self.value.__add__(other))
-        return self
-
-    def __sub__(self, other):
-        self._base_value_setter(self.value.__sub__(other))
-        return self
-
-    def __mul__(self, other):
-        self._base_value_setter(self.value.__mul__(other))
-        return self
-
-    def __matmul__(self, other):
-        self._base_value_setter(self.value.__matmul__(other))
-        return self
-
-    def __pow__(self, power, modulo=None):
-        self._base_value_setter(self.value.__pow__(power, modulo))
-        return self
