@@ -20,7 +20,7 @@ def test_conversfon():
 
 def test_math():
     f = Reffloat(555)
-    f += 10
+    f.value += 10
     assert f == 555+10
-    f -= 20
+    f.value -= 20
     assert f == 555-10
