@@ -29,7 +29,7 @@ def test_conversion():
 
 def test_math():
     i = RefInt(555)
-    i += 10
+    i.value += 10
     assert i == 555+10
-    i -= 20
+    i.value -= 20
     assert i == 555-10
